@@ -678,13 +678,16 @@ def add_miniscree_plots_from_scree_plot(df_examples: pd.DataFrame,
     nb_examples, _ = df_examples.shape
     duplicated_examples = utl.duplicate_data_wfold(df=scree_plot, window=window_size)
     if dropna:
-        duplicated_examples.dropna(axis='index', how='any', inplace=True)
+        duplicated_examples.dropna(axis=0, how='any', inplace=True)
     for ncomp in scree_plot.index:
         position = 0 if known_ncomp <= ncomp else window_size-1 if known_ncomp >= ncomp + window_size - 1 \
                 else known_ncomp - ncomp
 
         duplicated_examples.loc[ncomp, "Position"] = position
+    duplicated_examples.index += nb_examples
     df_examples = pd.concat([df_examples, duplicated_examples], axis=0)
+    if dropna:
+        df_examples.dropna(axis=0, how='any', inplace=True)
     return df_examples
 
 
