@@ -18,14 +18,17 @@ if __name__ == "__main__":
         formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
 
-    parser.add_argument("-o", "--output", type=str, default="wfold_scree_plots", help="Output file path")
+    parser.add_argument("-o", "--output", type=str, default="wfold_scree_plots.csv", help="Output file path")
     parser.add_argument("-r", "--runs", type=int, default=100, help="Number of iterations per node")
     parser.add_argument("-w", "--writefreq", type=int, default=20, help="Write frequency")
-    parser.add_argument("-e", "--epsilon", type=float, default=0.10, help="Other argument you need")
+    parser.add_argument("-e", "--epsilon", type=float, default=0.10, help="Epsilon")
+    parser.add_argument("-m", "--ncmin", type=float, default=2, help="Minimum number of components")
+    parser.add_argument("-M", "--ncmax", type=float, default=45, help="Maximum number of components")
     args = parser.parse_args()
     output = Path(args.output)
     epsilon = args.epsilon
-
+    ncmin = args.ncmin
+    ncmax = args.ncmax
     nruns = args.runs
     writefreq = args.writefreq
 
@@ -49,9 +52,13 @@ if __name__ == "__main__":
         # generated_M.to_csv(res_path / "random_nmf" / f"M_t{itrial}_nc{nb_clusters}_corrmin{round(min_corr,2)}_"
         #                                f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}.csv",
         #                    float_format="%.4f")
-        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=2, ncmax=10)
+        df_scree_plot = nmf.generate_scree_plot(generated_M, ncmin=ncmin, ncmax=ncmax)
         df_mini_scree_plots = nmf.add_miniscree_plots_from_scree_plot(df_mini_scree_plots, df_scree_plot, nb_clusters)
 
-#        if itrial % writefreq == 0:
-    output.write(df_mini_scree_plots)
+        if itrial % writefreq == 0:
+            print(f"Saving iteration {itrial}")
+            assert not df_mini_scree_plots.empty
+            output.to_csv(df_mini_scree_plots)
+            assert output.isfile()
+            assert not output.read().empty
 
