@@ -229,18 +229,18 @@ if __name__ == "__main__":
         # Expérience pour prouver que l'imputation de valeurs via SNMF
         # donne les meilleurs résultats quand on connait le nombre exact de composants
         # nb_clusters = np.random.randint(low=5, high=40)
-        nb_clusters = 10
-        min_corr = np.random.uniform(low=0.75, high=0.95)
-        min_corr = 0.80
-        max_corr = np.random.uniform(low=0.05, high=0.25)
-        max_corr = 0.20
+        nb_clusters = 5
+        min_corr = np.random.uniform(low=0.70, high=0.95)
+        # min_corr = 0.70
+        max_corr = np.random.uniform(low=0.05, high=0.30)
+        max_corr = 0.30
         h_size = np.random.randint(low=10, high=20)
-        h_size = 40
+        h_size = 200
         w_size = np.random.randint(low=10, high=100)
-        w_size = 80
-        rnd_norms = False
+        w_size = 200
+        rnd_norms = True
         # eps = np.random.uniform(low=0.0, high=0.25)
-        eps = 0
+        eps = 0.10
         gen_M, _, _, _ = rng.generate_nmf_reconstruction(n_comp=nb_clusters, n_feat=h_size, n_obs=w_size,
                                                          min_intra_corr=min_corr, max_inter_corr=max_corr, epsilon=eps,
                                                          random_norms=rnd_norms)
@@ -267,7 +267,10 @@ if __name__ == "__main__":
                     [imp_nmf_proxy, None],
                     [imp_nmf_proxy_mean_first, None]]
         imp_name = "RandomBlockMatrices_2"
-        imp_tester = imp.ImputerTester(mat=gen_M, name=f"{imp_name}_nc{nb_clusters}",
+        wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters,
+                                       min_corr, max_corr, eps, rnd_norms,
+                                       )
+        imp_tester = imp.ImputerTester(mat=gen_M, name=f"{imp_name}_{wh_name}",
                                        imputer=imp_nmf_proxy, ref_clst=None,
                                        clst=None, err_func="MSE")
         for imp in imputers:
@@ -303,8 +306,10 @@ if __name__ == "__main__":
 
             utl.censor_data(mat=gen_m, censored_indices=censor_indices, inplace=True)
             rnstr = "RandNorms" if random_norms else "ConstNorms"
-            wh_name = f"M{w_size}x{h_size}_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
-                      f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_indices}.csv"
+            wh_name = rng.generate_wh_name(w_size, h_size, nb_clusters,
+                                           min_corr, max_corr, eps, random_norms, censor_indices)
+            # wh_name = f"M{w_size}x{h_size}_nc{nb_clusters}_corrmin{round(min_corr,2)}_" \
+            #           f"corrmax{round(max_corr,2)}_noise{round(eps,2)}_{rnstr}_mis{censor_indices}.csv"
             gen_m.to_csv(res_path / "random_nmf" / wh_name,
                          float_format="%.4f")
             gen_m_nmf = nmf.NmfModel(mat=gen_m, ncomp=nb_clusters)
